# GenePattern Notebook extension for Jupyter

This is an extension for using GenePattern from within a Jupyter notebook.

Please see the [GenePattern Notebook documentation](http://genepattern.org/genepattern-notebooks) 
for full install and usability instructions.

## Installing

This extension can be installed through Docker Hub or PIP.

> docker pull genepattern/genepattern-notebook

or

> pip install genepattern-notebook